From 3c8227b935fdc9eda7a6cfacc2e0d0d189e7bb36 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?P=C3=A9ter=20Szil=C3=A1gyi?= <peterke@gmail.com>
Date: Wed, 20 May 2015 10:34:45 +0300
Subject: eth: fix odd method names in peer set

---
 eth/handler.go |  4 ++--
 eth/peer.go    | 10 +++++-----
 2 files changed, 7 insertions(+), 7 deletions(-)

(limited to 'eth')

diff --git a/eth/handler.go b/eth/handler.go
index 835097d84..8dd254b1a 100644
--- a/eth/handler.go
+++ b/eth/handler.go
@@ -350,7 +350,7 @@ func (pm *ProtocolManager) verifyTd(peer *peer, request newBlockMsgData) error {
 // sqrt(peers) to determine the amount of peers we broadcast to.
 func (pm *ProtocolManager) BroadcastBlock(hash common.Hash, block *types.Block) {
 	// Broadcast block to a batch of peers not knowing about it
-	peers := pm.peers.BlockLackingPeers(hash)
+	peers := pm.peers.PeersWithoutBlock(hash)
 	peers = peers[:int(math.Sqrt(float64(len(peers))))]
 	for _, peer := range peers {
 		peer.sendNewBlock(block)
@@ -363,7 +363,7 @@ func (pm *ProtocolManager) BroadcastBlock(hash common.Hash, block *types.Block)
 // sqrt(peers) to determine the amount of peers we broadcast to.
 func (pm *ProtocolManager) BroadcastTx(hash common.Hash, tx *types.Transaction) {
 	// Broadcast transaction to a batch of peers not knowing about it
-	peers := pm.peers.TxLackingPeers(hash)
+	peers := pm.peers.PeersWithoutTx(hash)
 	//FIXME include this again: peers = peers[:int(math.Sqrt(float64(len(peers))))]
 	for _, peer := range peers {
 		peer.sendTransaction(tx)
diff --git a/eth/peer.go b/eth/peer.go
index a23449acd..fdd815293 100644
--- a/eth/peer.go
+++ b/eth/peer.go
@@ -213,9 +213,9 @@ func (ps *peerSet) Len() int {
 	return len(ps.peers)
 }
 
-// BlockLackingPeers retrieves a list of peers that do not have a given block
-// in their set of known hashes.
-func (ps *peerSet) BlockLackingPeers(hash common.Hash) []*peer {
+// PeersWithoutBlock retrieves a list of peers that do not have a given block in
+// their set of known hashes.
+func (ps *peerSet) PeersWithoutBlock(hash common.Hash) []*peer {
 	ps.lock.RLock()
 	defer ps.lock.RUnlock()
 
@@ -228,9 +228,9 @@ func (ps *peerSet) BlockLackingPeers(hash common.Hash) []*peer {
 	return list
 }
 
 // TxLackingPeers retrieves a list of peers that do not have a given transaction
 // in their set of known hashes.
-func (ps *peerSet) TxLackingPeers(hash common.Hash) []*peer {
+func (ps *peerSet) PeersWithoutTx(hash common.Hash) []*peer {
 	ps.lock.RLock()
 	defer ps.lock.RUnlock()
 
@@ -228,9 +228,9 @@ func (ps *peerSet) BlockLackingPeers(hash common.Hash) []*peer {
 }
 
-// TxLackingPeers retrieves a list of peers that do not have a given transaction
+// PeersWithoutTx retrieves a list of peers that do not have a given transaction
 // in their set of known hashes.
-- 
cgit v1.2.3